from setuptools import setup

setup(
    name='steamcommunity',
    version='0.0.1',
    description='',
    long_description='',
    url='https://github.com/summer/steamcommunity',
    author='summer',
    packages=[],
    classifiers=['Development Status :: 1 - Planning'],
)
